Brand color palette and theme factory.
Utility methods (hex parsing, opacity) are intentionally omitted here — use ColorService and ColorExt instead.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- darkTheme → ThemeData
-
no setter
- lightTheme → ThemeData
-
no setter
Constants
- background → const Color
- backgroundDark → const Color
- error → const Color
- errorContainer → const Color
- info → const Color
- infoContainer → const Color
- onBackground → const Color
- onBackgroundDark → const Color
- onError → const Color
- onErrorContainer → const Color
- onInfo → const Color
- onInfoContainer → const Color
- onSuccess → const Color
- onSuccessContainer → const Color
- onSurface → const Color
- onSurfaceDark → const Color
- onSurfaceVariant → const Color
- onSurfaceVariantDark → const Color
- onWarning → const Color
- onWarningContainer → const Color
- outline → const Color
- outlineDark → const Color
- outlineVariant → const Color
- outlineVariantDark → const Color
- overlay → const Color
- overlayLight → const Color
- primary → const Color
- primaryDark → const Color
- primaryLight → const Color
- primarySwatch → const MaterialColor
- success → const Color
- successContainer → const Color
- surface → const Color
- surfaceDark → const Color
- surfaceVariant → const Color
- surfaceVariantDark → const Color
- warning → const Color
- warningContainer → const Color