Breakpoint enum

Inheritance
Available extensions

Values

mobile → const Breakpoint
tablet → const Breakpoint
desktop → const Breakpoint
widescreen → const Breakpoint

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isAtLeastDesktop bool
True for desktop and above.
no setter
isAtLeastTablet bool
True for tablet and above.
no setter
isDesktop bool
no setter
isMobile bool
no setter
isTablet bool
no setter
isWidescreen bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

maybeWhen<T>({T mobile()?, T tablet()?, T desktop()?, T widescreen()?, required T orElse()}) → T
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<T>({required T mobile(), required T tablet(), required T desktop(), T widescreen()?}) → T

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Breakpoint>
A constant List of the values in this enum, in order of their declaration.